@@ -32,11 +32,12 @@ print.causal_model <- function(x, ...) {
   if (!is.null(x$posterior_distribution) & !is.null(x$stan_objects)) {
     cat("\nModel has been updated and contains a posterior distribution with\n")
     cat(paste(x$stan_objects$stan_summary[[2]], "\n"))
-    cat("Use inspect(model, 'stan_objects') to inspect stan summary\n\n")
+    cat("Use inspect(model, 'stan_summary') to inspect stan summary\n\n")
 
     if(x$stan_objects$stan_warnings != "") {
       cat("Warnings passed from rstan during updating:\n")
-      cat(x$stan_objects$stan_warnings)
+      cat(paste(x$stan_objects$stan_warnings, "\n"))
+
     }
   }
 
@@ -134,14 +135,13 @@ summary.causal_model <- function(object, include = NULL, ...) {
         "prior_event_probabilities",
         "ambiguities_matrix",
         "type_prior",
-        "type_distribution",
+        "type_posterior",
         "posterior_distribution",
         "posterior_event_probabilities",
         "data",
-        "stanfit",
-        "stan_warnings",
         "stan_summary",
-        "stan_xs"
+        "stanfit",
+        "stan_warnings"
       ))
 
     if (length(wrong) > 0 & length(wrong) <= length(include)) {
@@ -229,13 +229,12 @@ summary.causal_model <- function(object, include = NULL, ...) {
 #'   \item \code{"prior_event_probabilities"} A vector of data (event) probabilities given a single (sepcified) parameter vector; for options see `"?get_event_probabilities"`,
 #'   \item \code{"ambiguities_matrix"} A matrix mapping from causal types into data types,
 #'   \item \code{"type_prior"} A matrix of type probabilities using priors,
-#'   \item \code{"type_distribution"} A matrix of type probabilities using posteriors,
+#'   \item \code{"type_posterior"} A matrix of type probabilities using posteriors,
 #'   \item \code{"posterior_distribution"} A data frame of the parameter posterior distribution,
 #'   \item \code{"posterior_event_probabilities"} A sample of data (event) probabilities from the posterior,
-#'   \item \code{"data"} A data frame with data that was used to update model.
+#'   \item \code{"data"} A data frame with data that was used to update model,
 #'   \item \code{"stanfit"} A `stanfit` object generated by Stan,
-#'   \item \code{"stan_summary"} A `stanfit` summary with updated parameter names,
-#'   \item \code{"stan_objects"} A list of Stan outputs that includes `stanfit`, `data`, and, if requested when updating the model, posterior `event_probabilities` and `type_distribution`.
+#'   \item \code{"stan_summary"} A `stanfit` summary with updated parameter names.
 #' }
 #'
 #' @examples
@@ -251,7 +250,7 @@ summary.causal_model <- function(object, include = NULL, ...) {
 #'     data = make_data(model, n = 100)
 #'   )
 #'
-#' print(summary(model), what = "type_distribution")
+#' print(summary(model), what = "type_posterior")
 #' print(summary(model), what = "posterior_distribution")
 #' print(summary(model), what = "posterior_event_probabilities")
 #' print(summary(model), what = "data_types")
@@ -262,7 +261,7 @@ summary.causal_model <- function(object, include = NULL, ...) {
 #' print(summary(model), what = "posterior_distribution")
 #' print(summary(model), what = "data")
 #' print(summary(model), what = "stanfit")
-#' print(summary(model), what = "type_distribution")
+#' print(summary(model), what = "type_posterior")
 #'
 #' # Large objects have to be added to the summary before printing
 #' print(summary(model, include = "ambiguities_matrix"),
@@ -356,11 +355,11 @@ print.summary.causal_model <-
             c(printout_upd, "'keep_event_probabilities = TRUE'")
         }
 
-        if (is.null(x$stan_objects$type_distribution)) {
+        if (is.null(x$stan_objects$type_posterior)) {
           printout <-
-            c(printout, "type_distribution")
+            c(printout, "type_posterior")
           printout_upd <-
-            c(printout_upd, "'type_distribution = TRUE'")
+            c(printout_upd, "'type_posterior = TRUE'")
         }
 
         if (is.null(x$stan_objects$stanfit)) {
@@ -396,6 +395,8 @@ print.summary.causal_model <-
       }
     }
 
+    ##########################################################################
+
     # specific printing requests:
 
     # pass on any additional elements to what from include argument in summary
@@ -405,16 +406,13 @@ print.summary.causal_model <-
     if(!short)
     what <- base::setdiff(what, c("statement", "nodal_types"))
 
-
-
     if(!is.null(what)) {
 
       # create dummy messages for updating
       printout <- c()
       printout_upd <- c()
 
-
-      ## IF WHAT IS SPECIFIED
+      ## when 'what' specified
 
       wrong <-
         base::setdiff(what, c(
@@ -435,14 +433,13 @@ print.summary.causal_model <-
           "prior_event_probabilities",
           "ambiguities_matrix",
           "type_prior",
-          "type_distribution",
+          "type_posterior",
           "posterior_distribution",
           "posterior_event_probabilities",
           "data",
-          "stanfit",
-          "stan_warnings",
           "stan_summary",
-          "stan_objects"
+          "stanfit",
+          "stan_warnings"
         ))
 
       if (length(wrong) > 0 & length(wrong) <= length(what)) {
@@ -494,7 +491,6 @@ print.summary.causal_model <-
         print(x$parameters)
       }
 
-
       # parameters_df
       if ("parameters_df" %in% what) {
         cat("\nparameters_df\nMapping of model parameters to nodal types: \n")
@@ -658,19 +654,19 @@ print.summary.causal_model <-
         warning("Model summary does not contain type_prior; to include this object use summary with 'include = 'type_prior''")
       }
 
-      # type_distribution
-      if ("type_distribution" %in% what) {
-        if (!is.null(x$stan_objects$type_distribution)) {
-          cat("\ntype_distribution\nPosterior draws of causal types (transformed parameters):\n")
+      # type_posterior
+      if ("type_posterior" %in% what) {
+        if (!is.null(x$stan_objects$type_posterior)) {
+          cat("\ntype_posterior\nPosterior draws of causal types (transformed parameters):\n")
           cat(paste(
             "\n  Distributions matrix dimensions are",
-            "\n ", dim(x$stan_objects$type_distribution)[1], "rows (draws) by",
-            dim(x$stan_objects$type_distribution)[2], "cols (causal types)\n\n",
+            "\n ", dim(x$stan_objects$type_posterior)[1], "rows (draws) by",
+            dim(x$stan_objects$type_posterior)[2], "cols (causal types)\n\n",
             sep = " "
           ))
           distribution_summary <-
             as.data.frame(t(apply(
-              x$stan_objects$type_distribution, 2,
+              x$stan_objects$type_posterior, 2,
               summarise_distribution
             )))
           rounding_threshold <- find_rounding_threshold(distribution_summary)
@@ -678,11 +674,11 @@ print.summary.causal_model <-
         } else {
           printout <- c(
             printout,
-            "posterior type_distribution"
+            "posterior type_posterior"
           )
           printout_upd <- c(
             printout_upd,
-            "'type_distribution = TRUE'"
+            "'type_posterior = TRUE'"
           )
         }
       }
@@ -776,7 +772,7 @@ print.summary.causal_model <-
       if ("stan_warnings" %in% what) {
         if (!is.null(x$stan_objects$stan_warnings)) {
           cat("\nstan_warnings\nStan warnings generated during updating:\n")
-          cat(x$stan_objects$stan_warnings)
+          cat(paste(x$stan_objects$stan_warnings, "\n"))
         } else {
           printout <- c(printout, "stan_warnings")
           printout_upd <- c(printout_upd, "'keep_fit = TRUE'")
@@ -784,19 +780,19 @@ print.summary.causal_model <-
       }
 
 
-      # stan_objects
+      # stan_objects: stan_summary
       if ("stan_summary" %in% what | "stan_objects" %in% what) {
         if (!is.null(x$stan_objects)) {
           cat("\nstan_summary\nStan model summary:\n")
-          print(x$stan_objects)
+          cat("\n")
+          cat(x$stan_objects$stan_summary, sep = "\n")
+
         } else {
           printout <- c(printout, "stan_objects")
           # printout_upd <- c(printout_upd, "")
         }
       }
 
-
-
       if (length(printout) > 0) {
         if (length(printout_upd) > 0) {
           stop(
@@ -830,7 +826,7 @@ print.summary.causal_model <-
       if(!is.null(x$posterior_distribution)){
         if(x$stan_objects$stan_warnings != "") {
           cat("Note: warnings passed from rstan during updating:\n")
-          cat(x$stan_objects$stan_warnings)
+          cat(paste(x$stan_objects$stan_warnings, "\n"))
         }}
 
     }
@@ -983,18 +979,3 @@ print_call_and_date <- function(object) {
 }
 
 
-#' Print a short summary for stan_objects
-#'
-#' print method for class \code{stan_objects}.
-#'
-#' @param x An object of the \code{stan_objects} class, which is a list
-#' containing the data, \code{type_distribution} and  \code{stan_summary}.
-#' @param ... Further arguments passed to or from other methods.
-#'
-#' @noRd
-#' @keywords internal
-print.stan_objects <- function(x, ...) {
-  cat("\n")
-  cat(x$stan_summary, sep = "\n")
-  return(invisible(x))
-}
