@@ -7,9 +7,9 @@ testthat::test_that(
 
 	code = {
 		## passer function
-		model_1 <- make_model('X -> Y') %>%
+		model_1 <- make_model('X -> Y') |>
 			set_confound('Y <-> X')
-		model_2 <- make_model('X -> Y') %>%
+		model_2 <- make_model('X -> Y') |>
 		  set_confound('Y <-> X')
 		expect_identical(model_1, model_2)
 	}
@@ -22,9 +22,9 @@ testthat::test_that(
 
   code = {
     ## passer function
-    model_1 <- make_model('X -> M -> Y') %>%
+    model_1 <- make_model('X -> M -> Y') |>
       set_confound(list('Y <-> X','Y <-> M'))
-    model_2 <- make_model('X -> M -> Y') %>%
+    model_2 <- make_model('X -> M -> Y') |>
       set_confound(list('Y <-> X','Y <-> M'))
     expect_identical(model_1, model_2)
   }
